@@ -1,11 +1,11 @@
 ;;; xwem-weather.el --- Display weather information in XWEM dock.
 
-;; Copyright (C) 2004 by Free Software Foundation, Inc.
+;; Copyright (C) 2004,2005 by XWEM Org.
 
 ;; Author: Steve Youngs <steve@youngs.au.com>
 ;; Created: 2004-06-22
 ;; Keywords: xwem
-;; X-CVS: $Id: xwem-weather.el,v 1.4 2005/01/01 04:43:03 youngs Exp $
+;; X-CVS: $Id: xwem-weather.el,v 1.5 2005/04/04 19:54:17 lg Exp $
 
 ;; This file is part of XWEM.
 
@@ -45,6 +45,7 @@
 (require 'xwem-osd)
 (require 'xwem-interactive)
 (require 'xwem-help)
+(require 'xwem-compat)
 
 (defgroup xwem-weather nil
   "XWEM Weather options."
@@ -90,6 +91,24 @@ weather station at http://weather.noaa.gov/"
   "*Face for the weather OSD."
   :group 'xwem-weather)
 
+(defvar xwem-weather-menu
+  '(["Show details" xwem-weather-show-details]
+    ["Update" xwem-weather-update]
+    "---"
+    ["Destroy" xwem-weather-remove])
+  "Menu to popup on `xwem-weather-popup-menu' command.
+NOTE: title for this menu is formated dynamically.")
+
+;;;###autoload(autoload 'xwem-weather-prefix "xwem-weather" nil nil 'keymap)
+(xwem-define-prefix-command 'xwem-weather-prefix t)
+(defvar xwem-weather-keymap (symbol-function 'xwem-weather-prefix)
+  "Keymap for weather commands.
+Bindings:
+\\{xwem-weather-keymap}")
+
+(define-key xwem-weather-keymap ?d 'xwem-weather-show-details)
+(define-key xwem-weather-keymap ?u 'xwem-weather-update)
+
 ;;; Internal variables
 
 (defvar xwem-weather-osd nil)
@@ -208,12 +227,13 @@ If you want to set this outside of the custom interface, you MUST use
     (erase-buffer)
     (insert-file-contents-literally xwem-weather-data-file)
     (goto-char (point-min))
-    (re-search-forward "^Temperature: \\(-?[0-9]+ F\\) (\\(-?[0-9]+ C\\))" nil t)
-    (let ((temp-f (match-string 1))
-          (temp-c (match-string 2)))
-      (if (eq xwem-weather-temperature-format 'celsius)
-          temp-c
-        temp-f))))
+    (when (re-search-forward
+           "^Temperature: \\(-?[0-9]+ F\\) (\\(-?[0-9]+ C\\))" nil t)
+      (let ((temp-f (match-string 1))
+            (temp-c (match-string 2)))
+        (if (eq xwem-weather-temperature-format 'celsius)
+            temp-c
+          temp-f)))))
 
 (defun xwem-weather-osd-text-width (text)
   "Return TEXT width."
@@ -249,6 +269,7 @@ If you want to set this outside of the custom interface, you MUST use
                                   :width 3 :height 3
                                   :angle1 0 :angle2 360))))
 
+;;;###autoload(autoload 'xwem-weather-update "xwem-weather" nil t)
 (define-xwem-command xwem-weather-update ()
   "*Update the weather OSD."
   (xwem-interactive "_")
@@ -257,12 +278,14 @@ If you want to set this outside of the custom interface, you MUST use
   (when (xwem-osd-p xwem-weather-osd)
     (xwem-weather-display-text (xwem-weather-get-temp))))
 
+;;;###autoload(autoload 'xwem-weather-show-details "xwem-weather" nil t)
 (define-xwem-command xwem-weather-show-details ()
   "*Show the details of the current weather information."
   (xwem-interactive)
   (xwem-help-display "weather"
    (insert-file-contents xwem-weather-data-file)))
 
+;;;###autoload(autoload 'xwem-weather-popup-remove "xwem-weather" nil t)
 (define-xwem-command xwem-weather-remove ()
   "*Remove the weather OSD."
   (xwem-interactive)
@@ -271,19 +294,16 @@ If you want to set this outside of the custom interface, you MUST use
   (when (itimerp (get-itimer "xwem-weather-itimer"))
     (delete-itimer (get-itimer "xwem-weather-itimer"))))
 
-(define-xwem-command xwem-weather-popup-menu ()
+;;;###autoload(autoload 'xwem-weather-popup-menu "xwem-weather" nil t)
+(define-xwem-command xwem-weather-popup-menu (ev)
   "Popup weather menu."
-  (xwem-interactive)
-  
-  (unless (button-event-p xwem-last-event)
-    (error 'xwem-error "`xwem-weather-popup-menu' must be bound to mouse event"))
-
+  (xwem-interactive (list xwem-last-event))
+  (unless (button-event-p ev)
+    (error 'xwem-error
+           "`xwem-weather-popup-menu' must be bound to mouse event"))
   (xwem-popup-menu
-   (list "Weather"
-         (vector "Show details" 'xwem-weather-show-details)
-         (vector "Update" 'xwem-weather-update)
-         "---"
-         (vector "Destroy" 'xwem-weather-remove))))
+   (cons (format "Weather (%s)" (upcase xwem-weather-station-id))
+         xwem-weather-menu)))
 
 (defvar xwem-weather-osd-keymap
   (let ((map (make-sparse-keymap 'xwem-weather-osd-keymap)))
@@ -310,15 +330,15 @@ If you want to set this outside of the custom interface, you MUST use
              (xwem-weather-osd-text-width text)
              (xwem-weather-osd-text-height text)
              (list 'keymap xwem-weather-osd-keymap)))
-      (xwem-osd-set-color xwem-weather-osd (face-foreground-name 'xwem-weather-osd-face))
-      (xwem-osd-set-font xwem-weather-osd (face-font-name 'xwem-weather-osd-face))
+      (xwem-osd-set-color xwem-weather-osd
+                          (face-foreground-name 'xwem-weather-osd-face))
+      (xwem-osd-set-font xwem-weather-osd
+                         (face-font-name 'xwem-weather-osd-face))
       
       ;; Do it so, `xwem-weather-osd-text-height' and
       ;; `xwem-weather-osd-text-height' will use mask's gc.
       (xwem-osd-create-mask xwem-weather-osd)
-
-      (xwem-weather-display-text text)
-      (xwem-osd-show xwem-weather-osd))))
+      (xwem-weather-display-text text))))
 
 ;;;###autoload
 (defun xwem-weather-init (&optional dockid dockgroup dockalign)
@@ -338,7 +358,6 @@ If you want to set this outside of the custom interface, you MUST use
 (provide 'xwem-weather)
 
 ;;; On-load actions
-(define-key xwem-global-map (xwem-kbd "H-c W d") 'xwem-weather-show-details)
-(define-key xwem-global-map (xwem-kbd "H-c W u") 'xwem-weather-update)
+(xwem-global-set-key (xwem-kbd "H-c W") 'xwem-weather-prefix)
 
 ;;; xwem-weather.el ends here
